//    Black Penguin - Game for Linux
//    Copyright (C) 1999 Holger Priebs, pengu@priebs.de
//
//    Holger Priebs
//    Hasselkamp 39
//    D - 24119 Kronshagen / Germany
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include "appwindow.h"
#include <qmessagebox.h>
#include "CRulesDialog.h"
#include "newgame.xpm"
#include "rules.xpm"
#include "load.xpm" 
#include "save.xpm"
#include "config.xpm"
// --------
// added by Olaf Hartig (9 Nov 1999)
#include "CConfigDialog.h"
// --------

const char* newGameText = "Start a new game. Beware of the Evil Window!";
const char* rulesGameText = "Show a short description of the game's rules."; 
const char* loadGameText = "Load a previously saved game.";
const char* saveGameText = "Save a game. Only one game can be saved at a time; any previously saved game will be overwritten.";

ApplicationWindow::ApplicationWindow()
    : QMainWindow( 0, "Black Penguin Main Window" )
{
	e = new BlackPenguinData( this, "blackpenguin" );
	e->setFocus();
	// reduce screen flickering
	e->setUpdatesEnabled(FALSE);
	setCentralWidget( e );

	fileTools = new QToolBar( this, "file operations" );

	newGameIcon = QPixmap( newgame_xpm );
	rulesIcon = QPixmap( rules_xpm );
	loadIcon = QPixmap( load_xpm );
	saveIcon = QPixmap( save_xpm );
	configIcon = QPixmap( config_xpm );

	QToolButton * newGame = new QToolButton( newGameIcon, "New Game", 0,
					      this, SLOT(reset()),
					      fileTools, "new game" );

	QToolButton* rulesGame = new QToolButton( rulesIcon, "Rules of the Game", 0,
						this, SLOT(rules()),
						fileTools, "rules game" );

	QToolButton* loadGame = new QToolButton( loadIcon, "Load Game", 0,
						this, SLOT(load()),
						fileTools, "load game" );

	QToolButton* saveGame = new QToolButton( saveIcon, "Save Game", 0,
						this, SLOT(save()),
						fileTools, "save game" );

	QPopupMenu* file = new QPopupMenu();
	QPopupMenu* help = new QPopupMenu();
	menuBar()->insertItem( "&File", file );
	menuBar()->insertItem( "&Help", help );

	file->insertItem( newGameIcon, "New Game", this, SLOT(reset()), Key_F2 );
	file->insertSeparator();
	file->insertItem( loadIcon, "Load Game", this, SLOT(load()), Key_F3 );
	file->insertItem( saveIcon, "Save Game", this, SLOT(save()), Key_F4 );
	file->insertSeparator();
// --------
// added by Olaf Hartig (9 Nov 1999) changed by Holger Priebs (16 Nov 1999)
	file->insertItem( configIcon, "Configure Keys", this, SLOT(config()), CTRL+Key_C );
	file->insertSeparator();
// --------
	file->insertItem( "Quit", this, SLOT(quit()), CTRL+Key_Q );

	help->insertItem( rulesIcon, "Rules of the Game", this, SLOT( rules() ), Key_F1 );
	help->insertSeparator();
	help->insertItem( "About &Black Penguin", this, SLOT( aboutp() ), Key_F5 );
	help->insertItem( "No &Warranty", this, SLOT( aboutw() ), Key_F6 );
	help->insertItem( "&Redistribution", this, SLOT( aboutc() ), Key_F7 );
	

	(void)QWhatsThis::whatsThisButton( fileTools );
	QWhatsThis::add( newGame, newGameText, FALSE );
	QWhatsThis::add( rulesGame, rulesGameText, FALSE );
	QWhatsThis::add( loadGame, loadGameText, FALSE );
	QWhatsThis::add( saveGame, saveGameText, FALSE );

	statusBar()->message( "Hit F2 to start a new Game", 5000 );

}

void ApplicationWindow::reset() {
	e->reset();
	statusBar()->message( "Game started.", 2000 );
}

void ApplicationWindow::save() {
	int retval;

	retval = e->savegame();
	switch (retval) {
		case 0:		statusBar()->message( "Game successfully saved.", 3000 );
				break;
		case 1:		statusBar()->message( "You cannot save a Game that is over.", 3000 );
				break;
		case 2:		statusBar()->message( "Could not save Game.", 3000 );
				break;
		default:	statusBar()->message( "Unknown error.", 3000 );
	}
}


void ApplicationWindow::load() {
	int retval;

	retval = e->loadgame();
	switch (retval) {
		case 0:		statusBar()->message( "Recently saved Game successfully loaded.", 3000 );
				break;
		case 1:		statusBar()->message( "Could not load Game.", 3000 );
				break;
		default:	statusBar()->message( "Unknown error.", 3000 );
	}
}

// --------
// added by Olaf Hartig 9 Nov 1999
void ApplicationWindow::config()
{
	CConfigDialog dlgConfig(e->getKeyNW(), e->getKeyNE(), e->getKeySW(), e->getKeySE(), this);
	connect(&dlgConfig, SIGNAL(newKeys(int,int,int,int)), e, SLOT(newKeys(int,int,int,int)) );
	dlgConfig.exec();
}
// --------

void ApplicationWindow::aboutp() {
	QMessageBox::message( "About Black Penguin", "Black Penguin 0.2b\nCopyright (C) \
1999 Holger Priebs <pengu@priebs.de>\n\n\
Thanks to:\n
Olaf Hartig <O.Hartig@keh-berlin.de> - Key Configuration\n\n
Black Penguin comes with ABSOLUTE NO WARRANTY: \n\
for details hit F6.\n\
This is free software, and you are welcome to redistribute it\n\
under certain conditions, hit F7 for details." );
}

void ApplicationWindow::aboutc() {
	QMessageBox::message( "Redistribution", "Black Penguin 0.2b\nCopyright (C) \
1999 Holger Priebs  <pengu@priebs.de>\n\n\

This program is free software; you can redistribute it and/or modify it\n\
under the terms of the GNU General Public Licence as published by the\n\
Free Software Foundation; either version 2 of the Licence, or (at your\n\
option) any later version.\n\n\
You should have received a copy of the GNU General Public Licence\n\
along with this program; if not, write to the Free Software Foundation,\n\
Inc., 675 Mass Ave, Cambridge, MA 02139, USA.");

}

void ApplicationWindow::aboutw() {
	QMessageBox::message( "No Warranty", "Black Penguin 0.2b\nCopyright (C) \
1999 Holger Priebs  <pengu@priebs.de>\n\n\
This program is distributed in the hope that it will be useful, but\n\
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTIBILITY\n\
or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public Licence\n\
for more details.\n\n\
You should have received a copy of the GNU General Public Licence\n\
along with this program; if not, write to the Free Software Foundation,\n\
Inc., 675 Mass Ave, Cambridge, MA 02139, USA.");

}

// show the 'rules of the game' dialog box (modal)

void ApplicationWindow::rules() {
	CRulesDialogData crdd(NULL, "bla");
	crdd.exec();	
};

void ApplicationWindow::quit() {
	close(TRUE);
}	


ApplicationWindow::~ApplicationWindow()
{
    // no explicit destruction 
}

